@@ -3,6 +3,7 @@ from ConfigParser import ConfigParser
 import os
 
 import config
+from insider.config import InsiderConfig
 import upnpc
 import port_mapper
 import dns
@@ -11,7 +12,8 @@ import cron
 
 class Insider:
 
-    def __init__(self, port_mapper, dns, cron):
+    def __init__(self, port_mapper, dns, cron, insider_config):
+        self.insider_config = insider_config
         self.port_mapper = port_mapper
         self.dns = dns
         self.cron = cron
@@ -40,6 +42,10 @@ class Insider:
     def acquire_domain(self, email, password, user_domain):
         return self.dns.acquire(email, password, user_domain)
 
+    def drop_domain(self):
+        self.dns.drop()
+        self.cron.off()
+
     def full_name(self):
         return self.dns.full_name()
 
@@ -49,18 +55,16 @@ class Insider:
     def cron_off(self):
         return self.cron.off()
 
+    def set_redirect_info(self, domain, api_url):
+        return self.insider_config.update(domain, api_url)
 
 def get_insider(bin_path, config_path, logs_path):
+
     script_path = os.path.join(bin_path, 'insidercli')
     insider_config_path = os.path.join(config_path, 'insider.cfg')
     cron_log_path = os.path.join(logs_path, 'insider-cron.log')
 
-    parser = ConfigParser()
-    parser.read(insider_config_path)
-
-    redirect_api_url = parser.get('redirect', 'api_url')
-    redirect_main_domain = parser.get('redirect', 'domain')
-    cron_period_mins = parser.getint('cron', 'period_mins')
+    insider_config = InsiderConfig(insider_config_path)
 
     domain_config_path = os.path.join(config_path, 'domain.json')
     services_config_path = os.path.join(config_path, 'services.json')
@@ -71,11 +75,14 @@ def get_insider(bin_path, config_path, logs_path):
     mapper = port_mapper.PortMapper(port_config, upnpclient)
     domain_config = config.DomainConfig(domain_config_path)
     service_config = config.ServiceConfig(services_config_path)
-    dns_service = dns.Dns(redirect_api_url, redirect_main_domain, domain_config, service_config, mapper)
 
-    cron_service = cron.Cron(script_path, cron_log_path, cron_period_mins)
+    dns_service = dns.Dns(
+        insider_config.get_redirect_api_url(),
+        insider_config.get_redirect_main_domain,
+        domain_config,
+        service_config,
+        mapper)
 
-    return Insider(mapper, dns_service, cron_service)
+    cron_service = cron.Cron(script_path, cron_log_path, insider_config.get_cron_period_mins())
 
-def get_deployed_insider():
-    return get_insider('/usr/local/bin', '/etc/config', '/var/log')
\ No newline at end of file
+    return Insider(mapper, dns_service, cron_service, insider_config)
\ No newline at end of file
